@@ -65,18 +65,6 @@ FAILEDOPERATION_CAYUNAPIAPPLYCERT = 'FailedOperation.CaYunApiApplyCert'
 # CFCA云API错误。
 FAILEDOPERATION_CAYUNAPICOMMON = 'FailedOperation.CaYunApiCommon'
 
-# 合约已在通道实例化。
-FAILEDOPERATION_CHAINCODECHANNEL = 'FailedOperation.ChainCodeChannel'
-
-# 合约已存在。
-FAILEDOPERATION_CHAINCODEEXIST = 'FailedOperation.ChainCodeExist'
-
-# 合约实例化错误。
-FAILEDOPERATION_CHAINCODEINIT = 'FailedOperation.ChainCodeInit'
-
-# 合约安装错误。
-FAILEDOPERATION_CHAINCODEINSTALL = 'FailedOperation.ChainCodeInstall'
-
 # Bcos不能编译已经部署的合约。
 FAILEDOPERATION_COMPILEDEPLOYEDCONTRACT = 'FailedOperation.CompileDeployedContract'
 
@@ -110,9 +98,6 @@ FAILEDOPERATION_FABRICCOMMIT = 'FailedOperation.FabricCommit'
 # event hub失败。
 FAILEDOPERATION_FABRICEVENTHUB = 'FailedOperation.FabricEventHub'
 
-# 区块链网络请求异常。
-FAILEDOPERATION_FABRICMANAGE = 'FailedOperation.FabricManage'
-
 # 背书失败。
 FAILEDOPERATION_FABRICPROPOSAL = 'FailedOperation.FabricProposal'
 
@@ -146,18 +131,6 @@ FAILEDOPERATION_FRONTREQUESTFAIL = 'FailedOperation.FrontRequestFail'
 # 用户非法操作。
 FAILEDOPERATION_GROUPILLEGAL = 'FailedOperation.GroupIllegal'
 
-# 无效合约。
-FAILEDOPERATION_INVALIDCHAINCODE = 'FailedOperation.InvalidChaincode'
-
-# 无效通道。
-FAILEDOPERATION_INVALIDCHANNEL = 'FailedOperation.InvalidChannel'
-
-# 无效网络。
-FAILEDOPERATION_INVALIDCLUSTER = 'FailedOperation.InvalidCluster'
-
-# 无效组织。
-FAILEDOPERATION_INVALIDGROUP = 'FailedOperation.InvalidGroup'
-
 # Bcos无效的群组编号。
 FAILEDOPERATION_INVALIDGROUPPK = 'FailedOperation.InvalidGroupPk'
 
@@ -167,12 +140,6 @@ FAILEDOPERATION_INVALIDKEYUSER = 'FailedOperation.InvalidKeyUser'
 # 无效操作。
 FAILEDOPERATION_INVALIDOPERATION = 'FailedOperation.InvalidOperation'
 
-# 无效节点。
-FAILEDOPERATION_INVALIDPEER = 'FailedOperation.InvalidPeer'
-
-# 无效资源。
-FAILEDOPERATION_INVALIDRESOURCE = 'FailedOperation.InvalidResource'
-
 # 交易请求异常。
 FAILEDOPERATION_MANAGESERVICE = 'FailedOperation.ManageService'
 
@@ -215,9 +182,6 @@ FAILEDOPERATION_TIMEOUTURL = 'FailedOperation.TimeOutUrl'
 # 交易执行超时，请稍后再试。
 FAILEDOPERATION_TRANSACTIONTIMEOUT = 'FailedOperation.TransactionTimeout'
 
-# Bcos更新已部署合约。
-FAILEDOPERATION_UPDATEDEPLOYEDCONTRACT = 'FailedOperation.UpdateDeployedContract'
-
 # 获取用户认证类型出错。
 FAILEDOPERATION_USERAUTHTYPE = 'FailedOperation.UserAuthType'
 
@@ -230,9 +194,6 @@ FAILEDOPERATION_USERNOJOINDEMOCLUSTER = 'FailedOperation.UserNoJoinDemoCluster'
 # Bcos数据库操作异常，请重试。
 INTERNALERROR_DBERROR = 'InternalError.DBError'
 
-# 内部错误。
-INTERNALERROR_FAILPREFORM = 'InternalError.FailPreform'
-
 # 服务器异常，请重试。
 INTERNALERROR_FAILURL = 'InternalError.FailUrl'
 
