@@ -32,6 +32,9 @@ FAILEDOPERATION_CLASSNOFOUND = 'FailedOperation.ClassNoFound'
 # 操作失败：不支持的封面类型。
 FAILEDOPERATION_COVERTYPE = 'FailedOperation.CoverType'
 
+# 操作失败：数据库操作失败。
+FAILEDOPERATION_DBERROR = 'FailedOperation.DBError'
+
 # 域名部署中，不能变更配置。
 FAILEDOPERATION_DOMAINDEPLOYING = 'FailedOperation.DomainDeploying'
 
@@ -50,6 +53,9 @@ FAILEDOPERATION_MEDIATYPE = 'FailedOperation.MediaType'
 # 网络错误。
 FAILEDOPERATION_NETWORKERROR = 'FailedOperation.NetWorkError'
 
+# 无需做降码率处理。
+FAILEDOPERATION_NONEEDTOREDUCEMEDIABITRATE = 'FailedOperation.NoNeedToReduceMediaBitrate'
+
 # 没有开通该接口使用权限。
 FAILEDOPERATION_NOPRIVILEGES = 'FailedOperation.NoPrivileges'
 
@@ -104,6 +110,9 @@ INVALIDPARAMETER_EXISTEDPROCEDURENAME = 'InvalidParameter.ExistedProcedureName'
 # 参数值错误：过期时间。
 INVALIDPARAMETER_EXPIRETIME = 'InvalidParameter.ExpireTime'
 
+# 参数错误：标签错误。
+INVALIDPARAMETER_LABELS = 'InvalidParameter.Labels'
+
 # 任务流模板名字不存在。
 INVALIDPARAMETER_PROCEDURENAMENOTEXIST = 'InvalidParameter.ProcedureNameNotExist'
 
@@ -344,6 +353,9 @@ INVALIDPARAMETERVALUE_KEYFRAMEDESCCONTENTTOOLONG = 'InvalidParameterValue.KeyFra
 # 参数值错误：LabelSet 参数取值非法。
 INVALIDPARAMETERVALUE_LABELSET = 'InvalidParameterValue.LabelSet'
 
+# 参数错误：标签错误。
+INVALIDPARAMETERVALUE_LABELS = 'InvalidParameterValue.Labels'
+
 # 参数错误：Limit。
 INVALIDPARAMETERVALUE_LIMIT = 'InvalidParameterValue.Limit'
 
@@ -359,7 +371,7 @@ INVALIDPARAMETERVALUE_MEDIATYPE = 'InvalidParameterValue.MediaType'
 # 参数值错误：媒体文件 URL。
 INVALIDPARAMETERVALUE_MEDIAURL = 'InvalidParameterValue.MediaUrl'
 
-# Metric 参数错误。
+# 参数错误：Metric 无效。
 INVALIDPARAMETERVALUE_METRIC = 'InvalidParameterValue.Metric'
 
 # 参数值错误：不允许修改默认模板。
@@ -608,12 +620,15 @@ LIMITEXCEEDED_KEYFRAMEDESCCOUNTREACHMAX = 'LimitExceeded.KeyFrameDescCountReachM
 # 超过限制值：新旧标签个数和超过限制值。
 LIMITEXCEEDED_TAGCOUNTREACHMAX = 'LimitExceeded.TagCountReachMax'
 
-# 超过限制值：模板数超限。
+# 超过限制值：模板数超过上限 100 个，如需更多请[提交工单](https://console.cloud.tencent.com/workorder/category)。
 LIMITEXCEEDED_TOOMUCHTEMPLATE = 'LimitExceeded.TooMuchTemplate'
 
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
+# 请求的次数超过了频率限制。
+REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'
+
 # 资源不存在。
 RESOURCENOTFOUND = 'ResourceNotFound'
 
