@@ -32,6 +32,9 @@ FAILEDOPERATION_BALANCEINSUFFICIENT = 'FailedOperation.BalanceInsufficient'
 # 不支持的地域。
 FAILEDOPERATION_INVALIDREGION = 'FailedOperation.InvalidRegion'
 
+# 不支持的IP类型。
+FAILEDOPERATION_IPTYPENOTPERMIT = 'FailedOperation.IpTypeNotPermit'
+
 # 未找到实例的主网卡。
 FAILEDOPERATION_MASTERENINOTFOUND = 'FailedOperation.MasterEniNotFound'
 
@@ -200,6 +203,9 @@ INVALIDPARAMETERVALUE_IPV6RULEIDEXISTED = 'InvalidParameterValue.IPv6RuleIdExist
 # IPv6规则没有更改。
 INVALIDPARAMETERVALUE_IPV6RULENOTCHANGE = 'InvalidParameterValue.IPv6RuleNotChange'
 
+# 资源格式错误
+INVALIDPARAMETERVALUE_ILLEGAL = 'InvalidParameterValue.Illegal'
+
 # 该实例的计费方式与其他实例不同。
 INVALIDPARAMETERVALUE_INCONSISTENTINSTANCEINTERNETCHARGETYPE = 'InvalidParameterValue.InconsistentInstanceInternetChargeType'
 
@@ -758,6 +764,9 @@ UNSUPPORTEDOPERATION_INCORRECTADDRESSRESOURCETYPE = 'UnsupportedOperation.Incorr
 # 用户配置的实例和路由表不匹配。
 UNSUPPORTEDOPERATION_INSTANCEANDRTBNOTMATCH = 'UnsupportedOperation.InstanceAndRtbNotMatch'
 
+# 当前云联网`%(value)s`的CdcId与传入实例的CdcId不一致，不支持关联。
+UNSUPPORTEDOPERATION_INSTANCECDCIDNOTMATCHCCNCDCID = 'UnsupportedOperation.InstanceCdcIdNotMatchCcnCdcId'
+
 # 指定实例资源不匹配。
 UNSUPPORTEDOPERATION_INSTANCEMISMATCH = 'UnsupportedOperation.InstanceMismatch'
 
